pub mod parser;

pub use crate::parser::*;

use std::io;
//use std::sync::Arc;

use tokio::net::TcpListener;
//use tokio::sync::RwLock;

const ADDR: &'static str = "0.0.0.0:7700";

#[tokio::main]
async fn main() {
    apiserver().await.unwrap();
    loop {
        std::thread::sleep(std::time::Duration::from_secs(1));
    }
}

pub async fn apiserver() -> io::Result<()> {
    let listener = match TcpListener::bind(ADDR).await {
        Ok(o) => o,
        Err(e) => {
            println!("error: {e}");
            std::process::exit(1);
        }
    };

    tokio::spawn(async move {
        loop {
            match listener.accept().await {
                Ok((socket, _remote_addr)) => {
                    let mut buf = vec![0; 256];

                    match socket.readable().await {
                        Ok(_) => {
                            match socket.try_read(&mut buf) {
                                Ok(_) => {}
                                Err(e) => {
                                    println!("error: {e}");
                                    continue;
                                }
                            };
                        }
                        Err(e) => {
                            println!("error: {e}");
                            continue;
                        }
                    }

                    let mut rawdata = buf.to_vec();
                    let msg = parse_inbound_msg(&mut rawdata);
                    println!("{:X?}", msg);
                }
                Err(err) => {
                    println!("error: {err}");
                }
            }
        }
    });
    Ok(())
}
