#[derive(Default, Debug)]
pub struct TerminalUniversalResponse {
    pub answer_serial_no: u16,
    pub answer_id: u16,
    pub result: u8,
}

impl BodyMessage for TerminalUniversalResponse {}

#[derive(Default, Debug)]
pub struct PlatformUniversalResponse {
    pub answer_serial_no: u16,
    pub answer_id: u16,
    pub result: u8,
}

#[derive(Default, Debug)]
pub struct TerminalHeartbeat {}

#[derive(Default, Debug)]
pub struct TerminalRegistration {
    pub provincial_id: u16,
    pub city_and_prefecture_id: u16,
    pub manufacturer_id: [u8; 5],
    pub terminal_models: [u8; 8],
    pub terminal_id: [u8; 7],
    pub license_plate_color: u8,
    pub license_plate: String,
}

#[derive(Default, Debug)]
pub struct TerminalRegistrationReply {
    pub answer_serial_no: u16,
    pub result: u8,
    pub authentication_code: String,
}

#[derive(Default, Debug)]
pub struct TerminalLogout {}

#[derive(Default, Debug)]
pub struct TerminalAuthentication {
    pub authentication_code: String,
}

#[derive(Default, Debug)]
pub struct TerminalParameterSetting {
    pub total_parameters: u8,
    pub parameters: Vec<TerminalParameterData>,
}

#[derive(Default, Debug)]
pub struct TerminalParameterData {
    pub parameter_id: u32,
    pub parameter_length: u8,
    pub parameter_value: u8,
}

#[derive(Default, Debug)]
pub struct QueryTerminalParameter {}

#[derive(Default, Debug)]
pub struct QueryTerminalParameterResponse {
    pub response_serial_no: u16,
    pub response_parameter_quantity: u16,
    pub parameters: Vec<TerminalParameterData>,
}

#[derive(Default, Debug)]
pub struct TerminalControl {
    pub command_word: u8,
    pub command_parameter: String,
}

#[derive(Default, Debug)]
pub struct LocationInformationReport {
    pub alert_mark: u32,
    pub status: u32,
    pub latitude: u32,
    pub longitude: u32,
    pub height: u32,
    pub speed: u32,
    pub direction: u32,
    pub time: u32,
}

#[derive(Default, Debug)]
pub struct StartOfTrip {}

#[derive(Default, Debug)]
pub struct EndOfTrip {}

#[derive(Debug)]
pub enum BodyType {
    TerminalUniversalResponse = 0x0001,
    PlatformUniversalResponse = 0x8001,
    TerminalHeartbeat = 0x0002,
    TerminalRegistration = 0x0100,
    TerminalRegistrationReply = 0x8100,
    TerminalLogout = 0x0003,
    TerminalAuthentication = 0x0102,
    TerminalParameterSetting = 0x8103,
    QueryTerminalParameter = 0x8104,
    QueryTerminalParameterResponse = 0x0104,
    TerminalControl = 0x8105,
    LocationInformationReport = 0x0200,
    StartOfTrip = 0x0202,
    EndOfTrip = 0x0203,
}

pub trait BodyMessage {
    fn parse() {}
}
